@@ -396,13 +396,9 @@ MainWindow::initQML ()
 
     // Prepare the globally accessible variants for QML.
     QDeclarativeContext *ctx = this->rootContext();
-    ctx->setContextProperty ("g_bShowMsg", bTempFalse);
-    ctx->setContextProperty ("g_registeredPhonesModel", &modelRegNumber);
     ctx->setContextProperty ("g_bIsLoggedIn", bTempFalse);
     ctx->setContextProperty ("g_bShowLoginSettings", bTempFalse);
     ctx->setContextProperty ("g_strStatus", "Getting Ready");
-    ctx->setContextProperty ("g_strMsgText", "No message");
-    ctx->setContextProperty ("g_CurrentPhoneName", "Not loaded");
     ctx->setContextProperty ("g_vmailPlayerState", iTempZero);
     ctx->setContextProperty ("g_logModel", QVariant::fromValue(arrLogMsgs));
     ctx->setContextProperty ("g_hMul", hMul);
@@ -469,7 +465,6 @@ MainWindow::initQML ()
                   this, SLOT   (on_actionE_xit_triggered ()));
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
-    if (!rv) { exit(1); }
     rv = connect (gObj, SIGNAL (sigMsgBoxDone(bool)),
                   this, SLOT (onSigMsgBoxDone(bool)));
     Q_ASSERT(rv);
@@ -489,6 +484,17 @@ MainWindow::initQML ()
     Q_ASSERT(rv);
     if (!rv) { exit(1); }
 
+    gObj = getQMLObject ("RegisteredPhonesView");
+    if (NULL == gObj) {
+        Q_WARN("Could not get to RegisteredPhonesView");
+        requestQuit ();
+        return;
+    }
+    rv = connect (gObj, SIGNAL (sigSelChanged (int)),
+                  this, SLOT   (onRegPhoneSelectionChange (int)));
+    Q_ASSERT(rv);
+    if (!rv) { exit(1); }
+
     // Now do the settings page
     if (!connectSettingsSignals ()) {
         exit (1);
@@ -751,6 +757,10 @@ MainWindow::gotAllRegisteredPhones (AsyncTaskToken *token)
 void
 MainWindow::onRegPhoneSelectionChange (int index)
 {
+    QObject *regView = getQMLObject ("RegisteredPhonesView");
+    Q_ASSERT(regView);
+    QMetaObject::invokeMethod (regView, "setSelected", Q_ARG(QVariant, index));
+
     indRegPhone = index;
 
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
@@ -761,9 +771,6 @@ MainWindow::onRegPhoneSelectionChange (int index)
         data.strName = "<Unknown>";
     }
 
-    QDeclarativeContext *ctx = this->rootContext();
-    ctx->setContextProperty ("g_CurrentPhoneName", data.strName);
-
     OsDependent &osd = Singletons::getRef().getOSD ();
     osd.setLongWork (this, false);
 
@@ -995,35 +1002,63 @@ MainWindow::refreshPinSettings()
 void
 MainWindow::showMsgBox (const QString &strMessage)
 {
-    QDeclarativeContext *ctx = this->rootContext();
-    ctx->setContextProperty ("g_bShowMsg", true);
-    ctx->setContextProperty ("g_strMsgText", strMessage);
+    QObject *obj = getQMLObject ("MsgBox");
+    if (NULL == obj) {
+        Q_ASSERT(obj);
+        return;
+    }
+
+    obj->setProperty ("msgText", strMessage);
+    obj->setProperty ("opacity", QVariant(1.0));
 }//MainWindow::showMsgBox
 
 void
-MainWindow::onSigMsgBoxDone (bool /*ok*/)
+MainWindow::onSigMsgBoxDone (bool /*ok = true*/)
 {
-    QDeclarativeContext *ctx = this->rootContext();
-    bool bTemp = false;
-    ctx->setContextProperty ("g_bShowMsg", bTemp);
+    QObject *obj = getQMLObject ("MsgBox");
+    if (NULL == obj) {
+        Q_ASSERT(obj);
+        return;
+    }
+
+    obj->setProperty ("opacity", QVariant(0.0));
 }//MainWindow::onSigMsgBoxDone
 
 void
 MainWindow::onCallInitiatorsChange (bool bSave)
 {
+    QObject *model = getQMLObject ("RegisteredPhonesModel");
+    Q_ASSERT(model);
+
     // Set the correct callback
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
     QString strCallback;
     bool bGotCallback = dbMain.getCallback (strCallback);
 
+    QVariantMap oneEntry;
+    QScriptEngine scriptEngine;
+    bool isChecked = false;
+
     QString strCiName;
+
+    // Clear out all entries in the model...
+    QMetaObject::invokeMethod (model, "clear");
     modelRegNumber.clear ();
-    for (int i = 0; i < arrNumbers.size (); i++)
-    {
+
+    for (int i = 0; i < arrNumbers.size (); i++) {
         strCiName = "Dial back: " + arrNumbers[i].strName;
         modelRegNumber.insertRow (strCiName,
                                   arrNumbers[i].strNumber,
                                   arrNumbers[i].chType);
+
+        oneEntry.clear ();
+        oneEntry["entryText"] = strCiName;
+        oneEntry["entryNumber"] = arrNumbers[i].strNumber;
+        oneEntry["entryType"] = arrNumbers[i].chType;
+        oneEntry["isChecked"] = isChecked;
+
+        QMetaObject::invokeMethod (model, "append",
+            Q_ARG(QScriptValue, scriptEngine.toScriptValue(oneEntry)));
     }
 
     // Store the callouts in the same widget as the callbacks
@@ -1032,6 +1067,15 @@ MainWindow::onCallInitiatorsChange (bool bSave)
         if (ci->isValid ()) {
             strCiName = "Dial out: " + ci->name ();
             modelRegNumber.insertRow (strCiName, ci->selfNumber (), ci);
+
+            oneEntry.clear ();
+            oneEntry["entryText"] = strCiName;
+            oneEntry["entryNumber"] = ci->selfNumber ();
+            oneEntry["entryType"] = 'O';
+            oneEntry["isChecked"] = isChecked;
+
+            QMetaObject::invokeMethod (model, "append",
+                Q_ARG(QScriptValue, scriptEngine.toScriptValue(oneEntry)));
         }
     }
 
